==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/ofpact/actions/ofpact/actions/nx/action/ct/mark/_case/NxActionCtMark.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions.nx.action.ct.mark._case;
import java.lang.Long;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.OfpactActions;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-action-ct-mark {
 *   leaf ct-mark {
 *     type uint32;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/ofpact-actions/ofpact-actions/nx-action-ct-mark-case/nx-action-ct-mark</i>
 *
 * <p>To create instances of this class use {@link NxActionCtMarkBuilder}.
 * @see NxActionCtMarkBuilder
 *
 */
public interface NxActionCtMark
    extends
    ChildOf<OfpactActions>,
    Augmentable<NxActionCtMark>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-ct-mark");

    /**
     * @return <code>java.lang.Long</code> <code>ctMark</code>, or <code>null</code> if not present
     */
    @Nullable Long getCtMark();

}

==> openflowplugin-extension-nicira-0.9.4-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/ofpact/actions/ofpact/actions/nx/action/ct/mark/_case/NxActionCtMark.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions.nx.action.ct.mark._case;
import java.lang.Class;
import java.lang.Long;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.OfpactActions;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-action-ct-mark {
 *   leaf ct-mark {
 *     type uint32;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/ofpact-actions/ofpact-actions/nx-action-ct-mark-case/nx-action-ct-mark</i>
 *
 * <p>To create instances of this class use {@link NxActionCtMarkBuilder}.
 * @see NxActionCtMarkBuilder
 *
 */
public interface NxActionCtMark
    extends
    ChildOf<OfpactActions>,
    Augmentable<NxActionCtMark>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-ct-mark");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions.nx.action.ct.mark._case.NxActionCtMark> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions.nx.action.ct.mark._case.NxActionCtMark.class;
    }
    
    /**
     * @return <code>java.lang.Long</code> <code>ctMark</code>, or <code>null</code> if not present
     */
    @Nullable Long getCtMark();

}
